==> adminer-3.2.1.zip: adminer-3.2.1/adminer/lang/ca.inc.php <==
<?php
$translations = array(
	'Login' => 'Inicia la sessió',
	'Logout successful.' => 'Desconnexió correcta.',
	'Invalid credentials.' => 'Credencials invàlids.',
	'Server' => 'Servidor',
	'Username' => 'Nom d\'usuari',
	'Password' => 'Contrasenya',
	'Select database' => 'Selecciona base de dades',
	'Invalid database.' => 'Base de dades invàlida.',
	'Create new database' => 'Crea una nova base de dades',
	'Table has been dropped.' => 'S\'ha suprimit la taula.',
	'Table has been altered.' => 'S\'ha modificat la taula.',
	'Table has been created.' => 'S\'ha creat la taula.',
	'Alter table' => 'Modifica la taula',
	'Create table' => 'Crea una taula',
	'Table name' => 'Nom de la taula',
	'engine' => 'motor',
	'collation' => 'compaginació',
	'Column name' => 'Nom de la columna',
	'Type' => 'Tipus',
	'Length' => 'Llargada',
	'Auto Increment' => 'Increment automàtic',
	'Options' => 'Opcions',
	'Save' => 'Desa',
	'Drop' => 'Suprimeix',
	'Database has been dropped.' => 'S\'ha suprimit la base de dades.',
	'Database has been created.' => 'S\'ha creat la base de dades.',
	'Database has been renamed.' => 'S\'ha canviat el nom de la base de dades.',
	'Database has been altered.' => 'S\'ha modificat la base de dades.',
	'Alter database' => 'Modifica la base de dades',
	'Create database' => 'Crea una base de dades',
	'SQL command' => 'Ordre SQL',
	'Dump' => 'Exporta',
	'Logout' => 'Desconnecta',
	'database' => 'base de dades',
	'Use' => 'Utilitza',
	'No tables.' => 'No hi ha cap taula.',
	'select' => 'registres',
	'Create new table' => 'Crea una nova taula',
	'Item has been deleted.' => 'S\'ha suprmit l\'element.',
	'Item has been updated.' => 'S\'ha actualitzat l\'element.',
	'Item%s has been inserted.' => 'S\'ha insertat l\'element%s.',
	'Edit' => 'Edita',
	'Insert' => 'Insereix',
	'Save and insert next' => 'Desa i insereix el següent',
	'Delete' => 'Suprimeix',
	'Database' => 'Base de dades',
	'Routines' => 'Rutines',
	'Indexes have been altered.' => 'S\'han modificat els índexs.',
	'Indexes' => 'Índexs',
	'Alter indexes' => 'Modifica els índexs',
	'Add next' => 'Afegeix el següent',
	'Language' => 'Idioma',
	'Select' => 'Selecciona',
	'New item' => 'Nou element',
	'Search' => 'Cerca',
	'Sort' => 'Ordena',
	'descending' => 'descendent',
	'Limit' => 'Límit',
	'No rows.' => 'No hi ha cap fila.',
	'Action' => 'Acció',
	'edit' => 'edita',
	'Page' => 'Plana',
	'Query executed OK, %d row(s) affected.' => array('Consulta executada correctament, %d fila modificada.', 'Consulta executada correctament, %d files modificades.'),
	'Error in query' => 'Error en la consulta',
	'Execute' => 'Executa',
	'Table' => 'Taula',
	'Foreign keys' => 'Claus foranes',
	'Triggers' => 'Activadors',
	'View' => 'Vista',
	'Unable to select the table' => 'Impossible seleccionar la taula',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF invàlid. Torna a enviar el formulari.',
	'Comment' => 'Comentari',
	'Default values' => 'Valors per defecte',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Cap comanda per executar.',
	'Unable to upload a file.' => 'Impossible adjuntar el fitxer.',
	'File upload' => 'Adjunta un fitxer',
	'File uploads are disabled.' => 'L\'ddjunció de fitxers està desactivada.',
	'Routine has been called, %d row(s) affected.' => array('S\'ha cridat la rutina, %d fila modificada.', 'S\'ha cridat la rutina, %d files modificades.'),
	'Call' => 'Crida',
	'No extension' => 'Cap extensió',
	'None of the supported PHP extensions (%s) are available.' => 'No hi ha cap de les extensions PHP soporatades (%s) disponible.',
	'Session support must be enabled.' => 'Cal que estigui permès l\'us de sessions.',
	'Session expired, please login again.' => 'La sessió ha expirat, torna a iniciar-ne una.',
	'Text length' => 'Longitud del text',
	'Foreign key has been dropped.' => 'S\'ha suprimit la clau forana.',
	'Foreign key has been altered.' => 'S\'ha modificat la clau forana.',
	'Foreign key has been created.' => 'S\'ha creat la clau forana.',
	'Foreign key' => 'Clau forana',
	'Target table' => 'Taula de destí',
	'Change' => 'Canvi',
	'Source' => 'Font',
	'Target' => 'Destí',
	'Add column' => 'Afegeix una columna',
	'Alter' => 'Modifica',
	'Add foreign key' => 'Afegeix una clau forana',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipus d\'índex',
	'Column (length)' => 'Columna (longitud)',
	'View has been dropped.' => 'S\'ha suprimit la vista.',
	'View has been altered.' => 'S\'ha modificat la vista.',
	'View has been created.' => 'S\'ha creat la vista.',
	'Alter view' => 'Modifica la vista',
	'Create view' => 'Crea una vista',
	'Name' => 'Nom',
	'Process list' => 'Llista de processos',
	'%d process(es) have been killed.' => array('S\'ha aturat %d procés.', 'S\'han aturat %d processos.'),
	'Kill' => 'Atura',
	'Parameter name' => 'Nom del paràmetre',
	'Database schema' => 'Esquema de la base de dades',
	'Create procedure' => 'Crea un procediment',
	'Create function' => 'Crea una funció',
	'Routine has been dropped.' => 'S\'ha suprimit la rutina.',
	'Routine has been altered.' => 'S\'ha modificat la rutina.',
	'Routine has been created.' => 'S\'ha creat la rutina.',
	'Alter function' => 'Modifica la funció',
	'Alter procedure' => 'Modifica el procediment',
	'Return type' => 'Tipus retornat',
	'Add trigger' => 'Afegeix un activador',
	'Trigger has been dropped.' => 'S\'ha suprimit l\'activador.',
	'Trigger has been altered.' => 'S\'ha modificat l\'activador.',
	'Trigger has been created.' => 'S\'ha creat l\'activador.',
	'Alter trigger' => 'Modifica l\'activador',
	'Create trigger' => 'Crea un activador',
	'Time' => 'Temps',
	'Event' => 'Event',
	'%s version: %s through PHP extension %s' => 'Versió %s: %s amb l\'extensió de PHP %s',
	'%d row(s)' => array('%d fila', '%d files'),
	'Remove' => 'Suprimeix',
	'Are you sure?' => 'Estàs segur?',
	'Privileges' => 'Privilegis',
	'Create user' => 'Crea un usuari',
	'User has been dropped.' => 'S\'ha suprimit l\'usuari.',
	'User has been altered.' => 'S\'ha modificat l\'usuari.',
	'User has been created.' => 'S\'ha creat l\'usuari.',
	'Hashed' => 'Hashed',
	'Column' => 'Columna',
	'Routine' => 'Rutina',
	'Grant' => 'Grant',
	'Revoke' => 'Revoke',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Les dades POST són massa grans. Redueix les dades o incrementa la directiva de configuració %s.',
	'Logged as: %s' => 'Connectat com: %s',
	'Move up' => 'Mou a dalt',
	'Move down' => 'Mou a baix',
	'Functions' => 'Funcions',
	'Aggregation' => 'Agregació',
	'Export' => 'Exporta',
	'Output' => 'Sortida',
	'open' => 'obre',
	'save' => 'desa',
	'Format' => 'Format',
	'Tables' => 'Taules',
	'Data' => 'Data',
	'Event has been dropped.' => 'S\'ha suprimit l\'event.',
	'Event has been altered.' => 'S\'ha modificat l\'event.',
	'Event has been created.' => 'S\'ha creat l\'event.',
	'Alter event' => 'Modifica l\'event',
	'Create event' => 'Crea un event',
	'At given time' => 'A un moment donat',
	'Every' => 'Cada',
	'Events' => 'Events',
	'Schedule' => 'Horari',
	'Start' => 'Comença',
	'End' => 'Acaba',
	'Status' => 'Estat',
	'On completion preserve' => 'Conservar en completar',
	'Tables and views' => 'Taules i vistes',
	'Data Length' => 'Longitud de les dades',
	'Index Length' => 'L\'ongitud de l\'índex',
	'Data Free' => 'Espai lliure',
	'Collation' => 'Compaginació',
	'Analyze' => 'Analitza',
	'Optimize' => 'Optimitza',
	'Check' => 'Verifica',
	'Repair' => 'Repara',
	'Truncate' => 'Escapça',
	'Tables have been truncated.' => 'S\'han escapçat les taules.',
	'Rows' => 'Files',
	',' => ',',
	'Tables have been moved.' => 'S\'han desplaçat les taules.',
	'Move to other database' => 'Desplaça a una altra base de dades',
	'Move' => 'Desplaça',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Desa i segueix editant',
	'original' => 'original',
	'%d item(s) have been affected.' => array('S\'ha modificat %d element.', 'S\'han modificat %d elements.'),
	'whole result' => 'tots els resultats',
	'Tables have been dropped.' => 'S\'han suprimit les taules.',
	'Clone' => 'Clona',
	'Partition by' => 'Fes particions segons',
	'Partitions' => 'Particions',
	'Partition name' => 'Nom de la partició',
	'Values' => 'Valors',
	'%d row(s) have been imported.' => array('S\'ha importat %d fila.', 'S\'han importat %d files.'),
	'Import' => 'Importa',
	'Show structure' => 'Mostra l\'estructura',
	'Select data' => 'Selecciona dades',
	'Stop on error' => 'Atura en trobar un error',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'S\'ha assolit el nombre màxim de camps. Incrementa %s i %s.',
	'anywhere' => 'a qualsevol lloc',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[aaaa]',
	'History' => 'Història',
	'Variables' => 'Variables',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Les columnes origen i destí han de ser del mateix tipus, la columna destí ha d\'estar indexada i les dades referenciades han d\'existir.',
	'E-mail' => 'Correu electrònic',
	'From' => 'De',
	'Subject' => 'Assumpte',
	'Send' => 'Envia',
	'%d e-mail(s) have been sent.' => array('S\'ha enviat %d correu electrònic.', 'S\'han enviat %d correus electrònics.'),
	'Run file' => 'Executa el fitxer',
	'Numbers' => 'Nombres',
	'Date and time' => 'Data i hora',
	'Strings' => 'Cadenes',
	'Binary' => 'Binari',
	'Lists' => 'Llistes',
	'Relations' => 'Relacions',
	'Maximum allowed file size is %sB.' => 'La mida màxima permesa del fitxer és de %sB.',
	'Clear' => 'Suprimeix',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Fitxer %s del servidor web',
	'File does not exist.' => 'El fitxer no existeix.',
	'Permanent login' => 'Sessió permanent',
	'%d in total' => '%d en total',
	'Attachments' => 'Adjuncions',
	'System' => 'Sistema',
	'last' => 'darrera',
	'Network' => 'Xarxa',
	'Geometry' => 'Geometria',
	'Databases have been dropped.' => 'S\'han suprimit les bases de dades.',
	'File exists.' => 'El fitxer ja existeix.',
	'Double click on a value to modify it.' => 'Fes un doble clic a un valor per modificar-lo.',
	'Use edit link to modify this value.' => 'Utilitza l\'enllaç d\'edició per modificar aquest valor.',
	'Alter schema' => 'Modifica l\'esquema',
	'Create schema' => 'Crea un esquema',
	'Schema has been dropped.' => 'S\'ha suprimit l\'esquema.',
	'Schema has been created.' => 'S\'ha creat l\'esquema.',
	'Schema has been altered.' => 'S\'ha modificat l\'esquema.',
	'schema' => 'esquema',
	'Schema' => 'Esquema',
	'Sequences' => 'Seqüències',
	'Create sequence' => 'Crea una seqüència',
	'Sequence has been dropped.' => 'S\'ha suprimit la seqüència.',
	'Sequence has been created.' => 'S\'ha creat la seqüència.',
	'Sequence has been altered.' => 'S\'ha modificat la seqüència.',
	'Alter sequence' => 'Modifica la seqüència',
	'User types' => 'Tipus de l\'usuari',
	'Create type' => 'Crea un tipus',
	'Type has been dropped.' => 'S\'ha suprimit el tipus.',
	'Type has been created.' => 'S\'ha creat el tipus.',
	'Alter type' => 'Modifica el tipus',
	'Search data in tables' => 'Cerca dades en les taules',
	'From server' => 'En el servidor',
	'empty' => 'buit',
	'now' => 'ara',
	'%d query(s) executed OK.' => array('%d consulta executada correctament.', '%d consultes executades correctament.'),
	'Show only errors' => 'Mostra només els errors',
	'Last page' => 'Darrera plana',
	'Refresh' => 'Refresca',
	'Invalid schema.' => 'Esquema invàlid.',
	'Please use one of the extensions %s.' => 'Si us plau, utilitza una de les extensions %s.',
	'ltr' => 'ltr',
);

==> adminer-3.6.1.zip: adminer-3.6.1/adminer/lang/ca.inc.php <==
<?php
$translations = array(
	'Login' => 'Inicia la sessió',
	'Logout successful.' => 'Desconnexió correcta.',
	'Invalid credentials.' => 'Credencials invàlids.',
	'Server' => 'Servidor',
	'Username' => 'Nom d\'usuari',
	'Password' => 'Contrasenya',
	'Select database' => 'Selecciona base de dades',
	'Invalid database.' => 'Base de dades invàlida.',
	'Create new database' => 'Crea una nova base de dades',
	'Table has been dropped.' => 'S\'ha suprimit la taula.',
	'Table has been altered.' => 'S\'ha modificat la taula.',
	'Table has been created.' => 'S\'ha creat la taula.',
	'Alter table' => 'Modifica la taula',
	'Create table' => 'Crea una taula',
	'Table name' => 'Nom de la taula',
	'engine' => 'motor',
	'collation' => 'compaginació',
	'Column name' => 'Nom de la columna',
	'Type' => 'Tipus',
	'Length' => 'Llargada',
	'Auto Increment' => 'Increment automàtic',
	'Options' => 'Opcions',
	'Save' => 'Desa',
	'Drop' => 'Suprimeix',
	'Database has been dropped.' => 'S\'ha suprimit la base de dades.',
	'Database has been created.' => 'S\'ha creat la base de dades.',
	'Database has been renamed.' => 'S\'ha canviat el nom de la base de dades.',
	'Database has been altered.' => 'S\'ha modificat la base de dades.',
	'Alter database' => 'Modifica la base de dades',
	'Create database' => 'Crea una base de dades',
	'SQL command' => 'Ordre SQL',
	'Dump' => 'Exporta',
	'Logout' => 'Desconnecta',
	'database' => 'base de dades',
	'Use' => 'Utilitza',
	'No tables.' => 'No hi ha cap taula.',
	'select' => 'registres',
	'Create new table' => 'Crea una nova taula',
	'Item has been deleted.' => 'S\'ha suprmit l\'element.',
	'Item has been updated.' => 'S\'ha actualitzat l\'element.',
	'Item%s has been inserted.' => 'S\'ha insertat l\'element%s.',
	'Edit' => 'Edita',
	'Insert' => 'Insereix',
	'Save and insert next' => 'Desa i insereix el següent',
	'Delete' => 'Suprimeix',
	'Database' => 'Base de dades',
	'Routines' => 'Rutines',
	'Indexes have been altered.' => 'S\'han modificat els índexs.',
	'Indexes' => 'Índexs',
	'Alter indexes' => 'Modifica els índexs',
	'Add next' => 'Afegeix el següent',
	'Language' => 'Idioma',
	'Select' => 'Selecciona',
	'New item' => 'Nou element',
	'Search' => 'Cerca',
	'Sort' => 'Ordena',
	'descending' => 'descendent',
	'Limit' => 'Límit',
	'No rows.' => 'No hi ha cap registre.',
	'Action' => 'Acció',
	'edit' => 'edita',
	'Page' => 'Plana',
	'Query executed OK, %d row(s) affected.' => array('Consulta executada correctament, %d registre modificat.', 'Consulta executada correctament, %d registres modificats.'),
	'Error in query' => 'Error en la consulta',
	'Execute' => 'Executa',
	'Table' => 'Taula',
	'Foreign keys' => 'Claus foranes',
	'Triggers' => 'Activadors',
	'View' => 'Vista',
	'Unable to select the table' => 'Impossible seleccionar la taula',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF invàlid. Torna a enviar el formulari.',
	'Comment' => 'Comentari',
	'Default values' => 'Valors per defecte',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Cap comanda per executar.',
	'Unable to upload a file.' => 'Impossible adjuntar el fitxer.',
	'File upload' => 'Adjunta un fitxer',
	'File uploads are disabled.' => 'L\'ddjunció de fitxers està desactivada.',
	'Routine has been called, %d row(s) affected.' => array('S\'ha cridat la rutina, %d registre modificat.', 'S\'ha cridat la rutina, %d registres modificats.'),
	'Call' => 'Crida',
	'No extension' => 'Cap extensió',
	'None of the supported PHP extensions (%s) are available.' => 'No hi ha cap de les extensions PHP soporatades (%s) disponible.',
	'Session support must be enabled.' => 'Cal que estigui permès l\'us de sessions.',
	'Session expired, please login again.' => 'La sessió ha expirat, torna a iniciar-ne una.',
	'Text length' => 'Longitud del text',
	'Foreign key has been dropped.' => 'S\'ha suprimit la clau forana.',
	'Foreign key has been altered.' => 'S\'ha modificat la clau forana.',
	'Foreign key has been created.' => 'S\'ha creat la clau forana.',
	'Foreign key' => 'Clau forana',
	'Target table' => 'Taula de destí',
	'Change' => 'Canvi',
	'Source' => 'Font',
	'Target' => 'Destí',
	'Add column' => 'Afegeix una columna',
	'Alter' => 'Modifica',
	'Add foreign key' => 'Afegeix una clau forana',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipus d\'índex',
	'Column (length)' => 'Columna (longitud)',
	'View has been dropped.' => 'S\'ha suprimit la vista.',
	'View has been altered.' => 'S\'ha modificat la vista.',
	'View has been created.' => 'S\'ha creat la vista.',
	'Alter view' => 'Modifica la vista',
	'Create view' => 'Crea una vista',
	'Name' => 'Nom',
	'Process list' => 'Llista de processos',
	'%d process(es) have been killed.' => array('S\'ha aturat %d procés.', 'S\'han aturat %d processos.'),
	'Kill' => 'Atura',
	'Parameter name' => 'Nom del paràmetre',
	'Database schema' => 'Esquema de la base de dades',
	'Create procedure' => 'Crea un procediment',
	'Create function' => 'Crea una funció',
	'Routine has been dropped.' => 'S\'ha suprimit la rutina.',
	'Routine has been altered.' => 'S\'ha modificat la rutina.',
	'Routine has been created.' => 'S\'ha creat la rutina.',
	'Alter function' => 'Modifica la funció',
	'Alter procedure' => 'Modifica el procediment',
	'Return type' => 'Tipus retornat',
	'Add trigger' => 'Afegeix un activador',
	'Trigger has been dropped.' => 'S\'ha suprimit l\'activador.',
	'Trigger has been altered.' => 'S\'ha modificat l\'activador.',
	'Trigger has been created.' => 'S\'ha creat l\'activador.',
	'Alter trigger' => 'Modifica l\'activador',
	'Create trigger' => 'Crea un activador',
	'Time' => 'Temps',
	'Event' => 'Event',
	'%s version: %s through PHP extension %s' => 'Versió %s: %s amb l\'extensió de PHP %s',
	'%d row(s)' => array('%d registre', '%d registres'),
	'Remove' => 'Suprimeix',
	'Are you sure?' => 'Estàs segur?',
	'Privileges' => 'Privilegis',
	'Create user' => 'Crea un usuari',
	'User has been dropped.' => 'S\'ha suprimit l\'usuari.',
	'User has been altered.' => 'S\'ha modificat l\'usuari.',
	'User has been created.' => 'S\'ha creat l\'usuari.',
	'Hashed' => 'Hashed',
	'Column' => 'Columna',
	'Routine' => 'Rutina',
	'Grant' => 'Grant',
	'Revoke' => 'Revoke',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Les dades POST són massa grans. Redueix les dades o incrementa la directiva de configuració %s.',
	'Logged as: %s' => 'Connectat com: %s',
	'Move up' => 'Mou a dalt',
	'Move down' => 'Mou a baix',
	'Functions' => 'Funcions',
	'Aggregation' => 'Agregació',
	'Export' => 'Exporta',
	'Output' => 'Sortida',
	'open' => 'obre',
	'save' => 'desa',
	'Format' => 'Format',
	'Tables' => 'Taules',
	'Data' => 'Dades',
	'Event has been dropped.' => 'S\'ha suprimit l\'event.',
	'Event has been altered.' => 'S\'ha modificat l\'event.',
	'Event has been created.' => 'S\'ha creat l\'event.',
	'Alter event' => 'Modifica l\'event',
	'Create event' => 'Crea un event',
	'At given time' => 'A un moment donat',
	'Every' => 'Cada',
	'Events' => 'Events',
	'Schedule' => 'Horari',
	'Start' => 'Comença',
	'End' => 'Acaba',
	'Status' => 'Estat',
	'On completion preserve' => 'Conservar en completar',
	'Tables and views' => 'Taules i vistes',
	'Data Length' => 'Longitud de les dades',
	'Index Length' => 'Longitud de l\'índex',
	'Data Free' => 'Espai lliure',
	'Collation' => 'Compaginació',
	'Analyze' => 'Analitza',
	'Optimize' => 'Optimitza',
	'Check' => 'Verifica',
	'Repair' => 'Repara',
	'Truncate' => 'Escapça',
	'Tables have been truncated.' => 'S\'han escapçat les taules.',
	'Rows' => 'Files',
	',' => ',',
	'Tables have been moved.' => 'S\'han desplaçat les taules.',
	'Move to other database' => 'Desplaça a una altra base de dades',
	'Move' => 'Desplaça',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Desa i segueix editant',
	'original' => 'original',
	'%d item(s) have been affected.' => array('S\'ha modificat %d element.', 'S\'han modificat %d elements.'),
	'whole result' => 'tots els resultats',
	'Tables have been dropped.' => 'S\'han suprimit les taules.',
	'Clone' => 'Clona',
	'Partition by' => 'Fes particions segons',
	'Partitions' => 'Particions',
	'Partition name' => 'Nom de la partició',
	'Values' => 'Valors',
	'%d row(s) have been imported.' => array('S\'ha importat %d registre.', 'S\'han importat %d registres.'),
	'Import' => 'Importa',
	'Show structure' => 'Mostra l\'estructura',
	'Select data' => 'Selecciona dades',
	'Stop on error' => 'Atura en trobar un error',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'S\'ha assolit el nombre màxim de camps. Incrementa %s i %s.',
	'anywhere' => 'a qualsevol lloc',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[aaaa]',
	'History' => 'Història',
	'Variables' => 'Variables',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Les columnes origen i destí han de ser del mateix tipus, la columna destí ha d\'estar indexada i les dades referenciades han d\'existir.',
	'E-mail' => 'Correu electrònic',
	'From' => 'De',
	'Subject' => 'Assumpte',
	'Send' => 'Envia',
	'%d e-mail(s) have been sent.' => array('S\'ha enviat %d correu electrònic.', 'S\'han enviat %d correus electrònics.'),
	'Run file' => 'Executa el fitxer',
	'Numbers' => 'Nombres',
	'Date and time' => 'Data i hora',
	'Strings' => 'Cadenes',
	'Binary' => 'Binari',
	'Lists' => 'Llistes',
	'Relations' => 'Relacions',
	'Maximum allowed file size is %sB.' => 'La mida màxima permesa del fitxer és de %sB.',
	'Clear' => 'Suprimeix',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Fitxer %s del servidor web',
	'File does not exist.' => 'El fitxer no existeix.',
	'Permanent login' => 'Sessió permanent',
	'%d in total' => '%d en total',
	'Attachments' => 'Adjuncions',
	'System' => 'Sistema',
	'last' => 'darrera',
	'Network' => 'Xarxa',
	'Geometry' => 'Geometria',
	'Databases have been dropped.' => 'S\'han suprimit les bases de dades.',
	'File exists.' => 'El fitxer ja existeix.',
	'Double click on a value to modify it.' => 'Fes un doble clic a un valor per modificar-lo.',
	'Use edit link to modify this value.' => 'Utilitza l\'enllaç d\'edició per modificar aquest valor.',
	'Alter schema' => 'Modifica l\'esquema',
	'Create schema' => 'Crea un esquema',
	'Schema has been dropped.' => 'S\'ha suprimit l\'esquema.',
	'Schema has been created.' => 'S\'ha creat l\'esquema.',
	'Schema has been altered.' => 'S\'ha modificat l\'esquema.',
	'schema' => 'esquema',
	'Schema' => 'Esquema',
	'Sequences' => 'Seqüències',
	'Create sequence' => 'Crea una seqüència',
	'Sequence has been dropped.' => 'S\'ha suprimit la seqüència.',
	'Sequence has been created.' => 'S\'ha creat la seqüència.',
	'Sequence has been altered.' => 'S\'ha modificat la seqüència.',
	'Alter sequence' => 'Modifica la seqüència',
	'User types' => 'Tipus de l\'usuari',
	'Create type' => 'Crea un tipus',
	'Type has been dropped.' => 'S\'ha suprimit el tipus.',
	'Type has been created.' => 'S\'ha creat el tipus.',
	'Alter type' => 'Modifica el tipus',
	'Search data in tables' => 'Cerca dades en les taules',
	'From server' => 'En el servidor',
	'empty' => 'buit',
	'now' => 'ara',
	'%d query(s) executed OK.' => array('%d consulta executada correctament.', '%d consultes executades correctament.'),
	'Show only errors' => 'Mostra només els errors',
	'Last page' => 'Darrera plana',
	'Refresh' => 'Refresca',
	'Invalid schema.' => 'Esquema invàlid.',
	'Please use one of the extensions %s.' => 'Si us plau, utilitza una de les extensions %s.',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'S\'han copiat les taules.',
	'Copy' => 'Còpia',
	'Permanent link' => 'Enllaç permanent',
	'Edit all' => 'Edita-ho tot',
	'HH:MM:SS' => 'HH:MM:SS',
);
